@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::Test::CheckBreaks; # git description: v0.011-10-ga86c7a7
+package Dist::Zilla::Plugin::Test::CheckBreaks; # git description: v0.012-12-geed72a8
 # ABSTRACT: Generate a test that shows what modules you are breaking
 # KEYWORDS: distribution prerequisites upstream dependencies modules conflicts breaks breakages metadata
-# vim: set ts=8 sts=4 sw=4 tw=78 et :
+# vim: set ts=8 sts=4 sw=4 tw=115 et :
 
-our $VERSION = '0.012';
+our $VERSION = '0.013';
 
 use Moose;
 with (
@@ -32,6 +32,7 @@ around dump_config => sub
 
     $config->{+__PACKAGE__} = {
         conflicts_module => $self->conflicts_module,
+        blessed($self) ne __PACKAGE__ ? ( version => $VERSION ) : (),
     };
 
     return $config;
@@ -74,6 +75,8 @@ has conflicts_module => (
     },
 );
 
+sub _cmc_prereq { '0.011' }
+
 sub munge_files
 {
     my $self = shift;
@@ -93,6 +96,7 @@ sub munge_files
                 plugin => \$self,
                 module => \($self->conflicts_module),
                 breaks => \$breaks_data,
+                cmc_prereq => \($self->_cmc_prereq),
             }
         )
     );
@@ -115,7 +119,7 @@ sub register_prereqs
         exists $distmeta->{x_breaks} && keys %{ $distmeta->{x_breaks} }
             ? (
                 'CPAN::Meta::Requirements' => '0',
-                'CPAN::Meta::Check' => '0.007',
+                'CPAN::Meta::Check' => $self->_cmc_prereq,
             ) : (),
     );
 }
@@ -211,7 +215,7 @@ Dist::Zilla::Plugin::Test::CheckBreaks - Generate a test that shows what modules
 
 =head1 VERSION
 
-version 0.012
+version 0.013
 
 =head1 SYNOPSIS
 
@@ -302,23 +306,36 @@ L<Module::Install::CheckConflicts>
 
 =back
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-Plugin-Test-CheckBreaks>
+(or L<bug-Dist-Zilla-Plugin-Test-CheckBreaks@rt.cpan.org|mailto:bug-Dist-Zilla-Plugin-Test-CheckBreaks@rt.cpan.org>).
+
+There is also a mailing list available for users of this distribution, at
+L<http://dzil.org/#mailing-list>.
+
+There is also an irc channel available for users of this distribution, at
+irc://irc.perl.org/#distzilla.
+
+I am also usually active on irc, as 'ether' at C<irc.perl.org>.
+
 =head1 AUTHOR
 
 Karen Etheridge <ether@cpan.org>
 
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2014 by Karen Etheridge.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =head1 CONTRIBUTOR
 
 =for stopwords Olivier Mengué
 
 Olivier Mengué <dolmen@cpan.org>
 
+=head1 COPYRIGHT AND LICENCE
+
+This software is copyright (c) 2014 by Karen Etheridge.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
 
 __DATA__
@@ -357,20 +374,23 @@ CHECK_CONFLICTS
         $dumper->Indent(1);
         $dumper->Useqq(1);
         my $dist_name = $dist->name;
-        'my ' . $dumper->Dump . <<'CHECK_BREAKS_1' .
+        '# this data duplicates x_breaks in META.json' . "\n"
+        . 'my ' . $dumper->Dump . <<'CHECK_BREAKS_1a'
 
 use CPAN::Meta::Requirements;
 my $reqs = CPAN::Meta::Requirements->new;
 $reqs->add_string_requirement($_, $breaks->{$_}) foreach keys %$breaks;
 
-use CPAN::Meta::Check 0.007 'check_requirements';
+CHECK_BREAKS_1a
+    . "use CPAN::Meta::Check $cmc_prereq 'check_requirements';\n"
+    . <<'CHECK_BREAKS_1b'
 our $result = check_requirements($reqs, 'conflicts');
 
 if (my @breaks = grep { defined $result->{$_} } keys %$result)
 {
-CHECK_BREAKS_1
-    "    diag 'Breakages found with $dist_name:';\n" .
-    <<'CHECK_BREAKS_2';
+CHECK_BREAKS_1b
+    . "    diag 'Breakages found with $dist_name:';\n"
+    . <<'CHECK_BREAKS_2';
     diag "$result->{$_}" for sort @breaks;
     diag "\n", 'You should now update these modules!';
 }
